# Generated by Django 3.2.5 on 2021-08-04 15:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_deep_link', '0006_auto_20210729_1527'),
    ]

    operations = [
        migrations.AlterField(
            model_name='visit',
            name='ip_data',
            field=models.JSONField(blank=True, default=dict, verbose_name='IP geodata'),
        ),
        migrations.AlterField(
            model_name='visit',
            name='query_data',
            field=models.JSONField(blank=True, default=dict, verbose_name='Query data'),
        ),
        migrations.AlterField(
            model_name='visit',
            name='ua_data',
            field=models.JSONField(blank=True, default=dict, verbose_name='User agent data'),
        ),
    ]
