# Generated by Django 3.2.5 on 2021-07-29 14:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_deep_link', '0004_auto_20210728_1722'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='visit',
            options={'default_permissions': ('delete', 'view')},
        ),
        migrations.AlterField(
            model_name='app',
            name='android_url',
            field=models.URLField(blank=True, help_text='Custom app download/coming soon page. If blank, users will not be redirected.', verbose_name='Android URL'),
        ),
        migrations.AlterField(
            model_name='app',
            name='default_url',
            field=models.URLField(help_text='Your fallback URL for platforms that do not have a specified redirect.', verbose_name='Default URL'),
        ),
        migrations.AlterField(
            model_name='app',
            name='ios_url',
            field=models.URLField(blank=True, help_text='Custom app download/coming soon page. If blank, users will not be redirected.', verbose_name='iOS URL'),
        ),
        migrations.AlterField(
            model_name='app',
            name='mac_app_store_url',
            field=models.URLField(blank=True, help_text='A URL to fallback to when the app is not installed.', max_length=255, verbose_name='Mac App Store URL'),
        ),
        migrations.AlterField(
            model_name='app',
            name='windows_app_store_url',
            field=models.URLField(blank=True, help_text='A URL to fallback to when the app is not installed.', max_length=255, verbose_name='Windows App Store URL'),
        ),
    ]
