# Generated by Django 3.2.5 on 2021-07-28 16:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_deep_link', '0002_auto_20210728_1540'),
    ]

    operations = [
        migrations.AlterField(
            model_name='app',
            name='mac_app',
            field=models.BooleanField(default=False, verbose_name='I have a Mac App'),
        ),
        migrations.AlterField(
            model_name='app',
            name='windows_app',
            field=models.BooleanField(default=False, verbose_name='I have a Windows App'),
        ),
    ]
